.. _recipe_asr.setup.params:

asr.setup.params
================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.setup.params`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.setup.params.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.setup.params

or as a python module

.. code-block:: console

   $ python -m asr.setup.params

Detailed description
--------------------
Generate parameter file 'params.json'.

Steps
-----


asr.setup.params
^^^^^^^^^^^^^^^^
.. autofunction:: asr.setup.params.main
   